@@ -22,9 +22,9 @@ class NasClient(AliCloudClient):
     def delete_file_system(self, query_params=None, body_params=None):
         return self.do_request(DeleteFileSystemRequest, query_params, body_params)
 
-    def describe_file_systems(self, query_params=None, body_params=None):
+    def describe_file_systems(self, query_params=None, body_params=None, set_params=None):
         try:
-            response = self.do_request(DescribeFileSystemsRequest, query_params, body_params)
+            response = self.do_request(DescribeFileSystemsRequest, query_params, body_params, set_params)
             return response
         except ServerException as e:
             if e.get_http_status() == 404:
