@@ -20,8 +20,8 @@ class HuaweiEvsClient(HuaweiClient):
         request = DeleteVolumeRequest(volume_id=volume_id)
         return self.evs_client.delete_volume(request)
 
-    def describe_volume(self, volume_id=None):
-        request = ListVolumesRequest(id=volume_id)
+    def describe_volume(self, volume_id=None, availability_zone=None):
+        request = ListVolumesRequest(id=volume_id, availability_zone=availability_zone)
         return self.evs_client.list_volumes(request).volumes
 
     def show_volume(self, volume_id=None):
