@@ -109,6 +109,11 @@ class HuaweiSecurityGroup:
     def delete(self):
         return hw_vpc_client.delete_securitygroup(security_group_id=self.id)
 
+    @classmethod
+    def list(cls):
+        sgs = hw_vpc_client.list_securitygroup()
+        return [cls(sg) for sg in sgs]
+
 
 class HuaweiSecurityGroupRule:
 
