@@ -4,8 +4,8 @@ import json
 
 class IntegrationMap(CMPClient):
 
-    def __init__(self, cmp_url, tenant_id):
-        super(IntegrationMap, self).__init__(cmp_url, tenant_id)
+    def __init__(self, cmp_url, tenant_id, cmp_secret_key, cmp_user_id):
+        super(IntegrationMap, self).__init__(cmp_url, tenant_id, cmp_secret_key, cmp_user_id)
 
     def create_integration_mapping(self, kwargs):
         """
