@@ -6,6 +6,7 @@ from .cfs_client import CfsClient
 from .vpc_client import VpcClient
 from .dns_client import DnsClient
 from .postgres_client import PostgresClient
+from .cbs_client import CbsClient
 
 prod_mapper = {
     'clb': ClbClient,
@@ -13,7 +14,8 @@ prod_mapper = {
     'cfs': CfsClient,
     'vpc': VpcClient,
     'dns': DnsClient,
-    'postgres': PostgresClient
+    'postgres': PostgresClient,
+    'cbs': CbsClient
 }
 
 
@@ -49,4 +51,9 @@ def dns_client():
 
 @proxy
 def postgres_client():
-    return get_current_client('postgres')
\ No newline at end of file
+    return get_current_client('postgres')
+
+
+@proxy
+def cbs_client():
+    return get_current_client('cbs')
\ No newline at end of file
